"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var CommandListener = /** @class */ (function () {
    function CommandListener(config, connection, registry) {
        this.config = config;
        this.connection = connection;
        this.registry = registry;
    }
    CommandListener.prototype.setupResources = function () {
        var queueName = this.config.appName + ".commands";
        var topicName = 'directMessages';
        var routingKey = this.config.appName;
        return Promise.all([
            this.declareCommandsQueue(queueName),
            this.declareDirectMessagesTopic(topicName),
            this.setupBindings(queueName, topicName, routingKey)
        ]).then();
    };
    CommandListener.prototype.startListening = function () {
        var _this = this;
        return this.connection.receiver.consume(this.config.appName + ".commands", function (message) {
            var command = message.data;
            var handler = _this.registry.getCommandHandler(command.name);
            return handler(command);
        });
    };
    CommandListener.prototype.declareCommandsQueue = function (queueName) {
        return this.connection.sender.declareQueue({
            name: queueName
        });
    };
    CommandListener.prototype.declareDirectMessagesTopic = function (topicName) {
        return this.connection.sender.declareTopic({
            name: topicName,
            type: 'direct'
        });
    };
    CommandListener.prototype.setupBindings = function (queueName, topicName, routingKey) {
        return this.connection.sender.bind({
            queue: queueName,
            topic: topicName,
            routingKey: routingKey
        });
    };
    return CommandListener;
}());
exports.CommandListener = CommandListener;
//# sourceMappingURL=command-listener.js.map