"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var command_listener_1 = require("./listeners/command-listener");
var event_listener_1 = require("./listeners/event-listener");
var query_listener_1 = require("./listeners/query-listener");
var reactive_commons_context_1 = require("./reactive-commons-context");
var ReactiveCommons = /** @class */ (function () {
    function ReactiveCommons(broker, registry, config) {
        this.broker = broker;
        this.registry = registry;
        this.config = config;
    }
    ReactiveCommons.prototype.start = function () {
        var connection = this.broker.connect();
        var messageListeners = [
            new event_listener_1.EventListener(this.config, connection, this.registry),
            new query_listener_1.QueryListener(this.config, connection, this.registry),
            new command_listener_1.CommandListener(this.config, connection, this.registry)
        ];
        var context = new reactive_commons_context_1.ReactiveCommonsContext(connection);
        return Promise.all(messageListeners.map(function (listener) {
            return Promise.all([listener.setupResources(), listener.startListening()]);
        })).then(function () { return context; });
    };
    return ReactiveCommons;
}());
exports.ReactiveCommons = ReactiveCommons;
//# sourceMappingURL=reactive-commons.js.map